@@ -711,7 +711,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             type Context = checkout_server::ServerContext;
 
             fn api_description() -> checkout_server::ApiDescription<checkout_server::ServerContext> {
-                let mut api = checkout_server::ApiDescription::<checkout_server::ServerContext>::new();
+                let mut api = checkout_server::ApiDescription::new();
                 api.register(checkout_server::create_endpoint).unwrap();
                 api.register(checkout_server::add_item_endpoint).unwrap();
                 api.register(checkout_server::remove_item_endpoint).unwrap();
